# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enterprise.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='enterprise.proto',
  package='Enterprise',
  syntax='proto3',
  serialized_options=b'\n\030com.keepersecurity.protoB\nEnterprise',
  serialized_pb=b'\n\x10\x65nterprise.proto\x12\nEnterprise\"\x84\x01\n\x18\x45nterpriseKeyPairRequest\x12\x1b\n\x13\x65nterprisePublicKey\x18\x01 \x01(\x0c\x12%\n\x1d\x65ncryptedEnterprisePrivateKey\x18\x02 \x01(\x0c\x12$\n\x07keyType\x18\x03 \x01(\x0e\x32\x13.Enterprise.KeyType\"\'\n\x14GetTeamMemberRequest\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\"U\n\x0e\x45nterpriseUser\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12\x65nterpriseUsername\x18\x03 \x01(\t\"K\n\x15GetTeamMemberResponse\x12\x32\n\x0e\x65nterpriseUser\x18\x01 \x03(\x0b\x32\x1a.Enterprise.EnterpriseUser\"-\n\x11\x45nterpriseUserIds\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x03(\x03\"B\n\x19\x45nterprisePersonalAccount\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x16\n\x0eOBSOLETE_FIELD\x18\x02 \x01(\x0c\"S\n\x17\x45ncryptedTeamKeyRequest\x12\x0f\n\x07teamUid\x18\x01 \x01(\x0c\x12\x18\n\x10\x65ncryptedTeamKey\x18\x02 \x01(\x0c\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\"+\n\x0fReEncryptedData\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"?\n\x12ReEncryptedRoleKey\x12\x0f\n\x07role_id\x18\x01 \x01(\x03\x12\x18\n\x10\x65ncryptedRoleKey\x18\x02 \x01(\x0c\"\x9d\x02\n\x1bNodeToManagedCompanyRequest\x12\x11\n\tcompanyId\x18\x01 \x01(\x05\x12*\n\x05nodes\x18\x02 \x03(\x0b\x32\x1b.Enterprise.ReEncryptedData\x12*\n\x05roles\x18\x03 \x03(\x0b\x32\x1b.Enterprise.ReEncryptedData\x12*\n\x05users\x18\x04 \x03(\x0b\x32\x1b.Enterprise.ReEncryptedData\x12\x30\n\x08roleKeys\x18\x05 \x03(\x0b\x32\x1e.Enterprise.ReEncryptedRoleKey\x12\x35\n\x08teamKeys\x18\x06 \x03(\x0b\x32#.Enterprise.EncryptedTeamKeyRequest\",\n\x08RoleTeam\x12\x0f\n\x07role_id\x18\x01 \x01(\x03\x12\x0f\n\x07teamUid\x18\x02 \x01(\x0c\"4\n\tRoleTeams\x12\'\n\trole_team\x18\x01 \x03(\x0b\x32\x14.Enterprise.RoleTeam\"\xc1\x03\n\x16\x45nterpriseRegistration\x12\x18\n\x10\x65ncryptedTreeKey\x18\x01 \x01(\x0c\x12\x16\n\x0e\x65nterpriseName\x18\x02 \x01(\t\x12\x14\n\x0crootNodeData\x18\x03 \x01(\x0c\x12\x15\n\radminUserData\x18\x04 \x01(\x0c\x12\x11\n\tadminName\x18\x05 \x01(\t\x12\x10\n\x08roleData\x18\x06 \x01(\x0c\x12\x38\n\nrsaKeyPair\x18\x07 \x01(\x0b\x32$.Enterprise.EnterpriseKeyPairRequest\x12\x13\n\x0bnumberSeats\x18\x08 \x01(\x05\x12\x32\n\x0e\x65nterpriseType\x18\t \x01(\x0e\x32\x1a.Enterprise.EnterpriseType\x12\x15\n\rrolePublicKey\x18\n \x01(\x0c\x12*\n\"rolePrivateKeyEncryptedWithRoleKey\x18\x0b \x01(\x0c\x12#\n\x1broleKeyEncryptedWithTreeKey\x18\x0c \x01(\x0c\x12\x38\n\neccKeyPair\x18\r \x01(\x0b\x32$.Enterprise.EnterpriseKeyPairRequest\".\n\x1a\x44omainPasswordRulesRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"\\\n\x19\x44omainPasswordRulesFields\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07minimum\x18\x02 \x01(\x05\x12\x0f\n\x07maximum\x18\x03 \x01(\x05\x12\x0f\n\x07\x61llowed\x18\x04 \x01(\x08\"g\n\x1b\x44omainPasswordRulesResponse\x12H\n\x19\x64omainPasswordRulesFields\x18\x01 \x03(\x0b\x32%.Enterprise.DomainPasswordRulesFields\"\x88\x01\n\x18\x41pproveUserDeviceRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x02 \x01(\x0c\x12\x1e\n\x16\x65ncryptedDeviceDataKey\x18\x03 \x01(\x0c\x12\x14\n\x0c\x64\x65nyApproval\x18\x04 \x01(\x08\"t\n\x19\x41pproveUserDeviceResponse\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1c\n\x14\x65ncryptedDeviceToken\x18\x02 \x01(\x0c\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\"Y\n\x19\x41pproveUserDevicesRequest\x12<\n\x0e\x64\x65viceRequests\x18\x01 \x03(\x0b\x32$.Enterprise.ApproveUserDeviceRequest\"\\\n\x1a\x41pproveUserDevicesResponse\x12>\n\x0f\x64\x65viceResponses\x18\x01 \x03(\x0b\x32%.Enterprise.ApproveUserDeviceResponse\"b\n\x15\x45nterpriseUserDataKey\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x1c\n\x14userEncryptedDataKey\x18\x02 \x01(\x0c\x12\x11\n\tkeyTypeId\x18\x03 \x01(\x05\"I\n\x16\x45nterpriseUserDataKeys\x12/\n\x04keys\x18\x01 \x03(\x0b\x32!.Enterprise.EnterpriseUserDataKey\".\n\x12UserDataKeyRequest\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x03(\x03\"Q\n\x1b\x45nterpriseUserIdDataKeyPair\x12\x18\n\x10\x65nterpriseUserId\x18\x01 \x01(\x03\x12\x18\n\x10\x65ncryptedDataKey\x18\x02 \x01(\x0c\"\x91\x01\n\x0bUserDataKey\x12\x0e\n\x06roleId\x18\x01 \x01(\x03\x12\x0f\n\x07roleKey\x18\x02 \x01(\x0c\x12\x12\n\nprivateKey\x18\x03 \x01(\t\x12M\n\x1c\x65nterpriseUserIdDataKeyPairs\x18\x04 \x03(\x0b\x32\'.Enterprise.EnterpriseUserIdDataKeyPair\"v\n\x13UserDataKeyResponse\x12-\n\x0cuserDataKeys\x18\x01 \x03(\x0b\x32\x17.Enterprise.UserDataKey\x12\x14\n\x0c\x61\x63\x63\x65ssDenied\x18\x02 \x03(\x03\x12\x1a\n\x12noEncryptedDataKey\x18\x03 \x03(\x03*\x1b\n\x07KeyType\x12\x07\n\x03RSA\x10\x00\x12\x07\n\x03\x45\x43\x43\x10\x01*=\n\x0e\x45nterpriseType\x12\x17\n\x13\x45NTERPRISE_STANDARD\x10\x00\x12\x12\n\x0e\x45NTERPRISE_MSP\x10\x01\x42&\n\x18\x63om.keepersecurity.protoB\nEnterpriseb\x06proto3'
)

_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='Enterprise.KeyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RSA', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ECC', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2785,
  serialized_end=2812,
)
_sym_db.RegisterEnumDescriptor(_KEYTYPE)

KeyType = enum_type_wrapper.EnumTypeWrapper(_KEYTYPE)
_ENTERPRISETYPE = _descriptor.EnumDescriptor(
  name='EnterpriseType',
  full_name='Enterprise.EnterpriseType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENTERPRISE_STANDARD', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENTERPRISE_MSP', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2814,
  serialized_end=2875,
)
_sym_db.RegisterEnumDescriptor(_ENTERPRISETYPE)

EnterpriseType = enum_type_wrapper.EnumTypeWrapper(_ENTERPRISETYPE)
RSA = 0
ECC = 1
ENTERPRISE_STANDARD = 0
ENTERPRISE_MSP = 1



_ENTERPRISEKEYPAIRREQUEST = _descriptor.Descriptor(
  name='EnterpriseKeyPairRequest',
  full_name='Enterprise.EnterpriseKeyPairRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterprisePublicKey', full_name='Enterprise.EnterpriseKeyPairRequest.enterprisePublicKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedEnterprisePrivateKey', full_name='Enterprise.EnterpriseKeyPairRequest.encryptedEnterprisePrivateKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyType', full_name='Enterprise.EnterpriseKeyPairRequest.keyType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=165,
)


_GETTEAMMEMBERREQUEST = _descriptor.Descriptor(
  name='GetTeamMemberRequest',
  full_name='Enterprise.GetTeamMemberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teamUid', full_name='Enterprise.GetTeamMemberRequest.teamUid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=206,
)


_ENTERPRISEUSER = _descriptor.Descriptor(
  name='EnterpriseUser',
  full_name='Enterprise.EnterpriseUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.EnterpriseUser.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='Enterprise.EnterpriseUser.email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enterpriseUsername', full_name='Enterprise.EnterpriseUser.enterpriseUsername', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=293,
)


_GETTEAMMEMBERRESPONSE = _descriptor.Descriptor(
  name='GetTeamMemberResponse',
  full_name='Enterprise.GetTeamMemberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUser', full_name='Enterprise.GetTeamMemberResponse.enterpriseUser', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=370,
)


_ENTERPRISEUSERIDS = _descriptor.Descriptor(
  name='EnterpriseUserIds',
  full_name='Enterprise.EnterpriseUserIds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.EnterpriseUserIds.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=417,
)


_ENTERPRISEPERSONALACCOUNT = _descriptor.Descriptor(
  name='EnterprisePersonalAccount',
  full_name='Enterprise.EnterprisePersonalAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='Enterprise.EnterprisePersonalAccount.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='OBSOLETE_FIELD', full_name='Enterprise.EnterprisePersonalAccount.OBSOLETE_FIELD', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=485,
)


_ENCRYPTEDTEAMKEYREQUEST = _descriptor.Descriptor(
  name='EncryptedTeamKeyRequest',
  full_name='Enterprise.EncryptedTeamKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teamUid', full_name='Enterprise.EncryptedTeamKeyRequest.teamUid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedTeamKey', full_name='Enterprise.EncryptedTeamKeyRequest.encryptedTeamKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='Enterprise.EncryptedTeamKeyRequest.force', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=570,
)


_REENCRYPTEDDATA = _descriptor.Descriptor(
  name='ReEncryptedData',
  full_name='Enterprise.ReEncryptedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Enterprise.ReEncryptedData.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='Enterprise.ReEncryptedData.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=615,
)


_REENCRYPTEDROLEKEY = _descriptor.Descriptor(
  name='ReEncryptedRoleKey',
  full_name='Enterprise.ReEncryptedRoleKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='Enterprise.ReEncryptedRoleKey.role_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedRoleKey', full_name='Enterprise.ReEncryptedRoleKey.encryptedRoleKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=680,
)


_NODETOMANAGEDCOMPANYREQUEST = _descriptor.Descriptor(
  name='NodeToManagedCompanyRequest',
  full_name='Enterprise.NodeToManagedCompanyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='companyId', full_name='Enterprise.NodeToManagedCompanyRequest.companyId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='Enterprise.NodeToManagedCompanyRequest.nodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roles', full_name='Enterprise.NodeToManagedCompanyRequest.roles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='users', full_name='Enterprise.NodeToManagedCompanyRequest.users', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roleKeys', full_name='Enterprise.NodeToManagedCompanyRequest.roleKeys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teamKeys', full_name='Enterprise.NodeToManagedCompanyRequest.teamKeys', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=968,
)


_ROLETEAM = _descriptor.Descriptor(
  name='RoleTeam',
  full_name='Enterprise.RoleTeam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_id', full_name='Enterprise.RoleTeam.role_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='teamUid', full_name='Enterprise.RoleTeam.teamUid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1014,
)


_ROLETEAMS = _descriptor.Descriptor(
  name='RoleTeams',
  full_name='Enterprise.RoleTeams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='role_team', full_name='Enterprise.RoleTeams.role_team', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1068,
)


_ENTERPRISEREGISTRATION = _descriptor.Descriptor(
  name='EnterpriseRegistration',
  full_name='Enterprise.EnterpriseRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encryptedTreeKey', full_name='Enterprise.EnterpriseRegistration.encryptedTreeKey', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enterpriseName', full_name='Enterprise.EnterpriseRegistration.enterpriseName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rootNodeData', full_name='Enterprise.EnterpriseRegistration.rootNodeData', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adminUserData', full_name='Enterprise.EnterpriseRegistration.adminUserData', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adminName', full_name='Enterprise.EnterpriseRegistration.adminName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roleData', full_name='Enterprise.EnterpriseRegistration.roleData', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rsaKeyPair', full_name='Enterprise.EnterpriseRegistration.rsaKeyPair', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberSeats', full_name='Enterprise.EnterpriseRegistration.numberSeats', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enterpriseType', full_name='Enterprise.EnterpriseRegistration.enterpriseType', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rolePublicKey', full_name='Enterprise.EnterpriseRegistration.rolePublicKey', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rolePrivateKeyEncryptedWithRoleKey', full_name='Enterprise.EnterpriseRegistration.rolePrivateKeyEncryptedWithRoleKey', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roleKeyEncryptedWithTreeKey', full_name='Enterprise.EnterpriseRegistration.roleKeyEncryptedWithTreeKey', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eccKeyPair', full_name='Enterprise.EnterpriseRegistration.eccKeyPair', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1520,
)


_DOMAINPASSWORDRULESREQUEST = _descriptor.Descriptor(
  name='DomainPasswordRulesRequest',
  full_name='Enterprise.DomainPasswordRulesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='Enterprise.DomainPasswordRulesRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1568,
)


_DOMAINPASSWORDRULESFIELDS = _descriptor.Descriptor(
  name='DomainPasswordRulesFields',
  full_name='Enterprise.DomainPasswordRulesFields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='Enterprise.DomainPasswordRulesFields.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum', full_name='Enterprise.DomainPasswordRulesFields.minimum', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='Enterprise.DomainPasswordRulesFields.maximum', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allowed', full_name='Enterprise.DomainPasswordRulesFields.allowed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1570,
  serialized_end=1662,
)


_DOMAINPASSWORDRULESRESPONSE = _descriptor.Descriptor(
  name='DomainPasswordRulesResponse',
  full_name='Enterprise.DomainPasswordRulesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='domainPasswordRulesFields', full_name='Enterprise.DomainPasswordRulesResponse.domainPasswordRulesFields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1767,
)


_APPROVEUSERDEVICEREQUEST = _descriptor.Descriptor(
  name='ApproveUserDeviceRequest',
  full_name='Enterprise.ApproveUserDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.ApproveUserDeviceRequest.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedDeviceToken', full_name='Enterprise.ApproveUserDeviceRequest.encryptedDeviceToken', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedDeviceDataKey', full_name='Enterprise.ApproveUserDeviceRequest.encryptedDeviceDataKey', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='denyApproval', full_name='Enterprise.ApproveUserDeviceRequest.denyApproval', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=1906,
)


_APPROVEUSERDEVICERESPONSE = _descriptor.Descriptor(
  name='ApproveUserDeviceResponse',
  full_name='Enterprise.ApproveUserDeviceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.ApproveUserDeviceResponse.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedDeviceToken', full_name='Enterprise.ApproveUserDeviceResponse.encryptedDeviceToken', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failed', full_name='Enterprise.ApproveUserDeviceResponse.failed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='Enterprise.ApproveUserDeviceResponse.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1908,
  serialized_end=2024,
)


_APPROVEUSERDEVICESREQUEST = _descriptor.Descriptor(
  name='ApproveUserDevicesRequest',
  full_name='Enterprise.ApproveUserDevicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceRequests', full_name='Enterprise.ApproveUserDevicesRequest.deviceRequests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2115,
)


_APPROVEUSERDEVICESRESPONSE = _descriptor.Descriptor(
  name='ApproveUserDevicesResponse',
  full_name='Enterprise.ApproveUserDevicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceResponses', full_name='Enterprise.ApproveUserDevicesResponse.deviceResponses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2117,
  serialized_end=2209,
)


_ENTERPRISEUSERDATAKEY = _descriptor.Descriptor(
  name='EnterpriseUserDataKey',
  full_name='Enterprise.EnterpriseUserDataKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.EnterpriseUserDataKey.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userEncryptedDataKey', full_name='Enterprise.EnterpriseUserDataKey.userEncryptedDataKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyTypeId', full_name='Enterprise.EnterpriseUserDataKey.keyTypeId', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2211,
  serialized_end=2309,
)


_ENTERPRISEUSERDATAKEYS = _descriptor.Descriptor(
  name='EnterpriseUserDataKeys',
  full_name='Enterprise.EnterpriseUserDataKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='Enterprise.EnterpriseUserDataKeys.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2311,
  serialized_end=2384,
)


_USERDATAKEYREQUEST = _descriptor.Descriptor(
  name='UserDataKeyRequest',
  full_name='Enterprise.UserDataKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.UserDataKeyRequest.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2432,
)


_ENTERPRISEUSERIDDATAKEYPAIR = _descriptor.Descriptor(
  name='EnterpriseUserIdDataKeyPair',
  full_name='Enterprise.EnterpriseUserIdDataKeyPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterpriseUserId', full_name='Enterprise.EnterpriseUserIdDataKeyPair.enterpriseUserId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryptedDataKey', full_name='Enterprise.EnterpriseUserIdDataKeyPair.encryptedDataKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2434,
  serialized_end=2515,
)


_USERDATAKEY = _descriptor.Descriptor(
  name='UserDataKey',
  full_name='Enterprise.UserDataKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='roleId', full_name='Enterprise.UserDataKey.roleId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roleKey', full_name='Enterprise.UserDataKey.roleKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='privateKey', full_name='Enterprise.UserDataKey.privateKey', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enterpriseUserIdDataKeyPairs', full_name='Enterprise.UserDataKey.enterpriseUserIdDataKeyPairs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2663,
)


_USERDATAKEYRESPONSE = _descriptor.Descriptor(
  name='UserDataKeyResponse',
  full_name='Enterprise.UserDataKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userDataKeys', full_name='Enterprise.UserDataKeyResponse.userDataKeys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accessDenied', full_name='Enterprise.UserDataKeyResponse.accessDenied', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noEncryptedDataKey', full_name='Enterprise.UserDataKeyResponse.noEncryptedDataKey', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2665,
  serialized_end=2783,
)

_ENTERPRISEKEYPAIRREQUEST.fields_by_name['keyType'].enum_type = _KEYTYPE
_GETTEAMMEMBERRESPONSE.fields_by_name['enterpriseUser'].message_type = _ENTERPRISEUSER
_NODETOMANAGEDCOMPANYREQUEST.fields_by_name['nodes'].message_type = _REENCRYPTEDDATA
_NODETOMANAGEDCOMPANYREQUEST.fields_by_name['roles'].message_type = _REENCRYPTEDDATA
_NODETOMANAGEDCOMPANYREQUEST.fields_by_name['users'].message_type = _REENCRYPTEDDATA
_NODETOMANAGEDCOMPANYREQUEST.fields_by_name['roleKeys'].message_type = _REENCRYPTEDROLEKEY
_NODETOMANAGEDCOMPANYREQUEST.fields_by_name['teamKeys'].message_type = _ENCRYPTEDTEAMKEYREQUEST
_ROLETEAMS.fields_by_name['role_team'].message_type = _ROLETEAM
_ENTERPRISEREGISTRATION.fields_by_name['rsaKeyPair'].message_type = _ENTERPRISEKEYPAIRREQUEST
_ENTERPRISEREGISTRATION.fields_by_name['enterpriseType'].enum_type = _ENTERPRISETYPE
_ENTERPRISEREGISTRATION.fields_by_name['eccKeyPair'].message_type = _ENTERPRISEKEYPAIRREQUEST
_DOMAINPASSWORDRULESRESPONSE.fields_by_name['domainPasswordRulesFields'].message_type = _DOMAINPASSWORDRULESFIELDS
_APPROVEUSERDEVICESREQUEST.fields_by_name['deviceRequests'].message_type = _APPROVEUSERDEVICEREQUEST
_APPROVEUSERDEVICESRESPONSE.fields_by_name['deviceResponses'].message_type = _APPROVEUSERDEVICERESPONSE
_ENTERPRISEUSERDATAKEYS.fields_by_name['keys'].message_type = _ENTERPRISEUSERDATAKEY
_USERDATAKEY.fields_by_name['enterpriseUserIdDataKeyPairs'].message_type = _ENTERPRISEUSERIDDATAKEYPAIR
_USERDATAKEYRESPONSE.fields_by_name['userDataKeys'].message_type = _USERDATAKEY
DESCRIPTOR.message_types_by_name['EnterpriseKeyPairRequest'] = _ENTERPRISEKEYPAIRREQUEST
DESCRIPTOR.message_types_by_name['GetTeamMemberRequest'] = _GETTEAMMEMBERREQUEST
DESCRIPTOR.message_types_by_name['EnterpriseUser'] = _ENTERPRISEUSER
DESCRIPTOR.message_types_by_name['GetTeamMemberResponse'] = _GETTEAMMEMBERRESPONSE
DESCRIPTOR.message_types_by_name['EnterpriseUserIds'] = _ENTERPRISEUSERIDS
DESCRIPTOR.message_types_by_name['EnterprisePersonalAccount'] = _ENTERPRISEPERSONALACCOUNT
DESCRIPTOR.message_types_by_name['EncryptedTeamKeyRequest'] = _ENCRYPTEDTEAMKEYREQUEST
DESCRIPTOR.message_types_by_name['ReEncryptedData'] = _REENCRYPTEDDATA
DESCRIPTOR.message_types_by_name['ReEncryptedRoleKey'] = _REENCRYPTEDROLEKEY
DESCRIPTOR.message_types_by_name['NodeToManagedCompanyRequest'] = _NODETOMANAGEDCOMPANYREQUEST
DESCRIPTOR.message_types_by_name['RoleTeam'] = _ROLETEAM
DESCRIPTOR.message_types_by_name['RoleTeams'] = _ROLETEAMS
DESCRIPTOR.message_types_by_name['EnterpriseRegistration'] = _ENTERPRISEREGISTRATION
DESCRIPTOR.message_types_by_name['DomainPasswordRulesRequest'] = _DOMAINPASSWORDRULESREQUEST
DESCRIPTOR.message_types_by_name['DomainPasswordRulesFields'] = _DOMAINPASSWORDRULESFIELDS
DESCRIPTOR.message_types_by_name['DomainPasswordRulesResponse'] = _DOMAINPASSWORDRULESRESPONSE
DESCRIPTOR.message_types_by_name['ApproveUserDeviceRequest'] = _APPROVEUSERDEVICEREQUEST
DESCRIPTOR.message_types_by_name['ApproveUserDeviceResponse'] = _APPROVEUSERDEVICERESPONSE
DESCRIPTOR.message_types_by_name['ApproveUserDevicesRequest'] = _APPROVEUSERDEVICESREQUEST
DESCRIPTOR.message_types_by_name['ApproveUserDevicesResponse'] = _APPROVEUSERDEVICESRESPONSE
DESCRIPTOR.message_types_by_name['EnterpriseUserDataKey'] = _ENTERPRISEUSERDATAKEY
DESCRIPTOR.message_types_by_name['EnterpriseUserDataKeys'] = _ENTERPRISEUSERDATAKEYS
DESCRIPTOR.message_types_by_name['UserDataKeyRequest'] = _USERDATAKEYREQUEST
DESCRIPTOR.message_types_by_name['EnterpriseUserIdDataKeyPair'] = _ENTERPRISEUSERIDDATAKEYPAIR
DESCRIPTOR.message_types_by_name['UserDataKey'] = _USERDATAKEY
DESCRIPTOR.message_types_by_name['UserDataKeyResponse'] = _USERDATAKEYRESPONSE
DESCRIPTOR.enum_types_by_name['KeyType'] = _KEYTYPE
DESCRIPTOR.enum_types_by_name['EnterpriseType'] = _ENTERPRISETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnterpriseKeyPairRequest = _reflection.GeneratedProtocolMessageType('EnterpriseKeyPairRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEKEYPAIRREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseKeyPairRequest)
  })
_sym_db.RegisterMessage(EnterpriseKeyPairRequest)

GetTeamMemberRequest = _reflection.GeneratedProtocolMessageType('GetTeamMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTEAMMEMBERREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetTeamMemberRequest)
  })
_sym_db.RegisterMessage(GetTeamMemberRequest)

EnterpriseUser = _reflection.GeneratedProtocolMessageType('EnterpriseUser', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSER,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUser)
  })
_sym_db.RegisterMessage(EnterpriseUser)

GetTeamMemberResponse = _reflection.GeneratedProtocolMessageType('GetTeamMemberResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTEAMMEMBERRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.GetTeamMemberResponse)
  })
_sym_db.RegisterMessage(GetTeamMemberResponse)

EnterpriseUserIds = _reflection.GeneratedProtocolMessageType('EnterpriseUserIds', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERIDS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserIds)
  })
_sym_db.RegisterMessage(EnterpriseUserIds)

EnterprisePersonalAccount = _reflection.GeneratedProtocolMessageType('EnterprisePersonalAccount', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEPERSONALACCOUNT,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterprisePersonalAccount)
  })
_sym_db.RegisterMessage(EnterprisePersonalAccount)

EncryptedTeamKeyRequest = _reflection.GeneratedProtocolMessageType('EncryptedTeamKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDTEAMKEYREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EncryptedTeamKeyRequest)
  })
_sym_db.RegisterMessage(EncryptedTeamKeyRequest)

ReEncryptedData = _reflection.GeneratedProtocolMessageType('ReEncryptedData', (_message.Message,), {
  'DESCRIPTOR' : _REENCRYPTEDDATA,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ReEncryptedData)
  })
_sym_db.RegisterMessage(ReEncryptedData)

ReEncryptedRoleKey = _reflection.GeneratedProtocolMessageType('ReEncryptedRoleKey', (_message.Message,), {
  'DESCRIPTOR' : _REENCRYPTEDROLEKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ReEncryptedRoleKey)
  })
_sym_db.RegisterMessage(ReEncryptedRoleKey)

NodeToManagedCompanyRequest = _reflection.GeneratedProtocolMessageType('NodeToManagedCompanyRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODETOMANAGEDCOMPANYREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.NodeToManagedCompanyRequest)
  })
_sym_db.RegisterMessage(NodeToManagedCompanyRequest)

RoleTeam = _reflection.GeneratedProtocolMessageType('RoleTeam', (_message.Message,), {
  'DESCRIPTOR' : _ROLETEAM,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleTeam)
  })
_sym_db.RegisterMessage(RoleTeam)

RoleTeams = _reflection.GeneratedProtocolMessageType('RoleTeams', (_message.Message,), {
  'DESCRIPTOR' : _ROLETEAMS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.RoleTeams)
  })
_sym_db.RegisterMessage(RoleTeams)

EnterpriseRegistration = _reflection.GeneratedProtocolMessageType('EnterpriseRegistration', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEREGISTRATION,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseRegistration)
  })
_sym_db.RegisterMessage(EnterpriseRegistration)

DomainPasswordRulesRequest = _reflection.GeneratedProtocolMessageType('DomainPasswordRulesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINPASSWORDRULESREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainPasswordRulesRequest)
  })
_sym_db.RegisterMessage(DomainPasswordRulesRequest)

DomainPasswordRulesFields = _reflection.GeneratedProtocolMessageType('DomainPasswordRulesFields', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINPASSWORDRULESFIELDS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainPasswordRulesFields)
  })
_sym_db.RegisterMessage(DomainPasswordRulesFields)

DomainPasswordRulesResponse = _reflection.GeneratedProtocolMessageType('DomainPasswordRulesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINPASSWORDRULESRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.DomainPasswordRulesResponse)
  })
_sym_db.RegisterMessage(DomainPasswordRulesResponse)

ApproveUserDeviceRequest = _reflection.GeneratedProtocolMessageType('ApproveUserDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICEREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDeviceRequest)
  })
_sym_db.RegisterMessage(ApproveUserDeviceRequest)

ApproveUserDeviceResponse = _reflection.GeneratedProtocolMessageType('ApproveUserDeviceResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICERESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDeviceResponse)
  })
_sym_db.RegisterMessage(ApproveUserDeviceResponse)

ApproveUserDevicesRequest = _reflection.GeneratedProtocolMessageType('ApproveUserDevicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICESREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDevicesRequest)
  })
_sym_db.RegisterMessage(ApproveUserDevicesRequest)

ApproveUserDevicesResponse = _reflection.GeneratedProtocolMessageType('ApproveUserDevicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEUSERDEVICESRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.ApproveUserDevicesResponse)
  })
_sym_db.RegisterMessage(ApproveUserDevicesResponse)

EnterpriseUserDataKey = _reflection.GeneratedProtocolMessageType('EnterpriseUserDataKey', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERDATAKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserDataKey)
  })
_sym_db.RegisterMessage(EnterpriseUserDataKey)

EnterpriseUserDataKeys = _reflection.GeneratedProtocolMessageType('EnterpriseUserDataKeys', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERDATAKEYS,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserDataKeys)
  })
_sym_db.RegisterMessage(EnterpriseUserDataKeys)

UserDataKeyRequest = _reflection.GeneratedProtocolMessageType('UserDataKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERDATAKEYREQUEST,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserDataKeyRequest)
  })
_sym_db.RegisterMessage(UserDataKeyRequest)

EnterpriseUserIdDataKeyPair = _reflection.GeneratedProtocolMessageType('EnterpriseUserIdDataKeyPair', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISEUSERIDDATAKEYPAIR,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.EnterpriseUserIdDataKeyPair)
  })
_sym_db.RegisterMessage(EnterpriseUserIdDataKeyPair)

UserDataKey = _reflection.GeneratedProtocolMessageType('UserDataKey', (_message.Message,), {
  'DESCRIPTOR' : _USERDATAKEY,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserDataKey)
  })
_sym_db.RegisterMessage(UserDataKey)

UserDataKeyResponse = _reflection.GeneratedProtocolMessageType('UserDataKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERDATAKEYRESPONSE,
  '__module__' : 'enterprise_pb2'
  # @@protoc_insertion_point(class_scope:Enterprise.UserDataKeyResponse)
  })
_sym_db.RegisterMessage(UserDataKeyResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
